@@ -56,10 +56,10 @@ Rcpp::List logQR(arma::vec& y, arma::mat& X, arma::mat& C, arma::vec alpha, arma
   }
     
   double p1 = 0.5*3*n*log(sigma);
-  double p2 = accu((1/(2*sigma*ep22))*(vn%pow(residule,2)-2*residule*ep1+vp*pow(ep22,2)/4));
+  double p2 = accu((1/(2*sigma*ep22))*(vn%pow(residule,2)-2*residule*ep1+vp*pow(ep1,2)))+accu(vp)/sigma-accu(log(vp))/2;
   double p3 = accu(abs(beta)%invS);
   double p4 = accu(gamma*log(theta)+(1-gamma)*log(1-theta));
-  double logver = -p1-p2-p3+p4-accu(pow(alpha,2)/2000)+(a+1)*log(sigma)-(b/sigma);
+  double logver = -p1-p2-p3+p4-accu(pow(alpha,2)/2000)-(a+1)*log(sigma)-(b/sigma);
   
   return Rcpp::List::create(Rcpp::Named("logver") = logver,
                             Rcpp::Named("Pgamma") = gamma,
